Stan Math Library: stan/math/mix/mat/fun/typedefs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

typedefs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_MIX_MAT_FUN_TYPEDEFS_HPP
2 #define STAN_MATH_MIX_MAT_FUN_TYPEDEFS_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/rev/core.hpp>
7 #include <stan/math/fwd/mat/fun/Eigen_NumTraits.hpp>
8
9 namespace stan {
10 namespace math {
11
12 typedef
13 Eigen::Matrix<fvar<var>, Eigen::Dynamic, Eigen::Dynamic>
14 matrix_fv;
15
16 typedef
17 Eigen::Matrix<fvar<fvar<var> >, Eigen::Dynamic, Eigen::Dynamic>
18 matrix_ffv;
19
20 typedef
21 Eigen::Matrix<fvar<var>, Eigen::Dynamic, 1>
22 vector_fv;
23
24 typedef
25 Eigen::Matrix<fvar<fvar<var> >, Eigen::Dynamic, 1>
26 vector_ffv;
27
28 typedef
29 Eigen::Matrix<fvar<var>, 1, Eigen::Dynamic>
30 row_vector_fv;
31
32 typedef
33 Eigen::Matrix<fvar<fvar<var> >, 1, Eigen::Dynamic>
34 row_vector_ffv;
35
36 }
37 }
38 #endif
stan::math::matrix_fv
Eigen::Matrix< fvar< var >, Eigen::Dynamic, Eigen::Dynamic > matrix_fv
Definition: typedefs.hpp:14
core.hpp
core.hpp
stan::math::vector_ffv
Eigen::Matrix< fvar< fvar< var > >, Eigen::Dynamic, 1 > vector_ffv
Definition: typedefs.hpp:26
stan
Definition: log_sum_exp.hpp:8
Eigen_NumTraits.hpp
stan::math::row_vector_fv
Eigen::Matrix< fvar< var >, 1, Eigen::Dynamic > row_vector_fv
Definition: typedefs.hpp:30
stan::math::row_vector_ffv
Eigen::Matrix< fvar< fvar< var > >, 1, Eigen::Dynamic > row_vector_ffv
Definition: typedefs.hpp:34
Eigen.hpp
stan::math::vector_fv
Eigen::Matrix< fvar< var >, Eigen::Dynamic, 1 > vector_fv
Definition: typedefs.hpp:22
stan::math::matrix_ffv
Eigen::Matrix< fvar< fvar< var > >, Eigen::Dynamic, Eigen::Dynamic > matrix_ffv
Definition: typedefs.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.